@@ -9,7 +9,8 @@ sub render {
 	my $rows = $caller->$n;
 	my @strs;
 	my $wl = $the_list->containee->Widgets_List;
-	my @names = map { $_->name } grep { /^HTML::.*Serializer/ } @$wl;
+	my @names = map { $_->name } grep {
+		$_->isa('HTML::Tested::JavaScript::Serializer::Value') } @$wl;
 
 	for my $r (@{ $stash->{ $n } }) {
 		push @strs, join(",\n\t", grep { defined($_) }
